//
//  AppDelegate_Phone.m
//  PantsTest
//
//  Created by Craig Hockenberry on 3/24/10.
//  Copyright The Iconfactory 2010. All rights reserved.
//

#import "AppDelegate_Phone.h"

#import <stdio.h>
#import <string.h>

#import <mach/mach_host.h>
#import <sys/sysctl.h>

@implementation AppDelegate_Phone

@synthesize window;

static void printMemoryInfo()
{
	size_t length;
	int mib[6];	
	int result;

	NSLog(@"Memory Info\n");
	NSLog(@"-----------\n");

	int pagesize;
	mib[0] = CTL_HW;
	mib[1] = HW_PAGESIZE;
	length = sizeof(pagesize);
	if (sysctl(mib, 2, &pagesize, &length, NULL, 0) < 0)
	{
		perror("getting page size");
	}
	NSLog(@"Page size = %d bytes\n", pagesize);
	NSLog(@"\n");

	mach_msg_type_number_t count = HOST_VM_INFO_COUNT;
	
	vm_statistics_data_t vmstat;
	if (host_statistics(mach_host_self(), HOST_VM_INFO, (host_info_t)&vmstat, &count) != KERN_SUCCESS)
	{
		NSLog(@"Failed to get VM statistics.");
	}
	
	double total = vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count;
	double wired = vmstat.wire_count / total;
	double active = vmstat.active_count / total;
	double inactive = vmstat.inactive_count / total;
	double free = vmstat.free_count / total;

	NSLog(@"Total =    %8d pages\n", vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count);
	NSLog(@"\n");
	NSLog(@"Wired =    %8d bytes\n", vmstat.wire_count * pagesize);
	NSLog(@"Active =   %8d bytes\n", vmstat.active_count * pagesize);
	NSLog(@"Inactive = %8d bytes\n", vmstat.inactive_count * pagesize);
	NSLog(@"Free =     %8d bytes\n", vmstat.free_count * pagesize);
	NSLog(@"\n");
	NSLog(@"Total =    %8d bytes\n", (vmstat.wire_count + vmstat.active_count + vmstat.inactive_count + vmstat.free_count) * pagesize);
	NSLog(@"\n");
	NSLog(@"Wired =    %0.2f %%\n", wired * 100.0);
	NSLog(@"Active =   %0.2f %%\n", active * 100.0);
	NSLog(@"Inactive = %0.2f %%\n", inactive * 100.0);
	NSLog(@"Free =     %0.2f %%\n", free * 100.0);
	NSLog(@"\n");

	mib[0] = CTL_HW;
	mib[1] = HW_PHYSMEM;
	length = sizeof(result);
	if (sysctl(mib, 2, &result, &length, NULL, 0) < 0)
	{
		perror("getting physical memory");
	}
	NSLog(@"Physical memory = %8d bytes\n", result);
	mib[0] = CTL_HW;
	mib[1] = HW_USERMEM;
	length = sizeof(result);
	if (sysctl(mib, 2, &result, &length, NULL, 0) < 0)
	{
		perror("getting user memory");
	}
	NSLog(@"User memory =     %8d bytes\n", result);
	NSLog(@"\n");
}

static void printProcessorInfo()
{
	size_t length;
	int mib[6];	
	int result;

	NSLog(@"Processor Info\n");
	NSLog(@"--------------\n");

	mib[0] = CTL_HW;
	mib[1] = HW_CPU_FREQ;
	length = sizeof(result);
	if (sysctl(mib, 2, &result, &length, NULL, 0) < 0)
	{
		perror("getting cpu frequency");
	}
	NSLog(@"CPU Frequency = %d hz\n", result);
	
	mib[0] = CTL_HW;
	mib[1] = HW_BUS_FREQ;
	length = sizeof(result);
	if (sysctl(mib, 2, &result, &length, NULL, 0) < 0)
	{
		perror("getting bus frequency");
	}
	NSLog(@"Bus Frequency = %d hz\n", result);
}

- (void)test;
{
    int x;
    x = 0;
}

- (BOOL)application:(UIApplication *)application didFinishLaunchingWithOptions:(NSDictionary *)launchOptions {    
	
	NSDate *startDate;
	NSDate *endDate;
	NSTimeInterval timeInterval;

	startDate = [NSDate date];
    {
        int i;
        int x = 0;
        for (i = 0; i < 100000; i++)
        {
            x = 0;
        }
    }
	endDate = [NSDate date];
	timeInterval = [endDate timeIntervalSinceDate:startDate];
	NSLog(@"Benchmark 1 took %f seconds.", timeInterval);

	startDate = [NSDate date];
    {
        int i;
        int x = 0;
        for (i = 1; i < 10001; i++)
        {
            x = 10000 / i;
        }
    }
	endDate = [NSDate date];
	timeInterval = [endDate timeIntervalSinceDate:startDate];
	NSLog(@"Benchmark 2 took %f seconds.", timeInterval);
    
	startDate = [NSDate date];
    {
        int i;
        int x = 0;
        for (i = 0; i < 10000; i++)
        {
            x = sinf((float)i);
        }
    }
	endDate = [NSDate date];
	timeInterval = [endDate timeIntervalSinceDate:startDate];
	NSLog(@"Benchmark 3 took %f seconds.", timeInterval);
    
	startDate = [NSDate date];
    {
        int i;
        NSString *x = nil;
        for (i = 0; i < 10000; i++)
        {
            x = [NSString string];
            unsigned int y = [x length];
        }
    }
	endDate = [NSDate date];
	timeInterval = [endDate timeIntervalSinceDate:startDate];
	NSLog(@"Benchmark 4 took %f seconds.", timeInterval);
    
	startDate = [NSDate date];
    {
        int i;
        for (i = 0; i < 10000; i++)
        {
            [self test];
        }
    }
	endDate = [NSDate date];
	timeInterval = [endDate timeIntervalSinceDate:startDate];
	NSLog(@"Benchmark 5 took %f seconds.", timeInterval);


	printMemoryInfo();
	printProcessorInfo();

	exit(0);

	
    [window makeKeyAndVisible];
	
	return YES;
}


- (void)dealloc {
    [window release];
    [super dealloc];
}


@end
